/* 
 * CVS identifier:
 * 
 * $Id: jj2000_j2k_util_NativeServices.c,v 1.6 2000/09/05 09:21:55 grosbois Exp $
 * 
 * Class:                   jj2000_j2k_util_NativeServices
 * 
 * Description:             JNI implementation of native methods in the class
 *                          jj2000.j2k.util.NativeServices.
 * 
 * 
 * 
 * COPYRIGHT:
 * 
 * This software module was originally developed by Raphal Grosbois and
 * Diego Santa Cruz (Swiss Federal Institute of Technology-EPFL); Joel
 * Askelf (Ericsson Radio Systems AB); and Bertrand Berthelot, David
 * Bouchard, Flix Henry, Gerard Mozelle and Patrice Onno (Canon Research
 * Centre France S.A) in the course of development of the JPEG2000
 * standard as specified by ISO/IEC 15444 (JPEG 2000 Standard). This
 * software module is an implementation of a part of the JPEG 2000
 * Standard. Swiss Federal Institute of Technology-EPFL, Ericsson Radio
 * Systems AB and Canon Research Centre France S.A (collectively JJ2000
 * Partners) agree not to assert against ISO/IEC and users of the JPEG
 * 2000 Standard (Users) any of their rights under the copyright, not
 * including other intellectual property rights, for this software module
 * with respect to the usage by ISO/IEC and Users of this software module
 * or modifications thereof for use in hardware or software products
 * claiming conformance to the JPEG 2000 Standard. Those intending to use
 * this software module in hardware or software products are advised that
 * their use may infringe existing patents. The original developers of
 * this software module, JJ2000 Partners and ISO/IEC assume no liability
 * for use of this software module or modifications thereof. No license
 * or right to this software module is granted for non JPEG 2000 Standard
 * conforming products. JJ2000 Partners have full right to use this
 * software module for his/her own purpose, assign or donate this
 * software module to any third party and to inhibit third parties from
 * using this software module for non JPEG 2000 Standard conforming
 * products. This copyright notice must be included in all copies or
 * derivative works of this software module.
 * 
 * Copyright (c) 1999/2000 JJ2000 Partners.
 * 
 * 
 * 
 */

/*
 * This file implements the native parts of the jj2000.j2k.util.NativeServices 
 * class using JNI. See that class' documentation for more details.
 *
 * Functions in this file use the POSIX threads library (pthread). However, it 
 * should not be linked against 'pthread' since they are compiled into a
 * shared library and the 'pthread' library is already loaded into the Java
 * runtime. Loading it twice can cause some problems.
 */

/* Include the class header generated by javah */
#include <jj2000_j2k_util_NativeServices.h>
/* Include the POSIX threads header */
#include <pthread.h>

/*
 * Class:     jj2000_j2k_util_NativeServices
 * Method:    setThreadConcurrencyN
 * Signature: (I)V
 */
/*
 * This function sets the concurrency level for threads with
 * PTHREAD_SCOPE_PROCESS scope scheduling.
 */
JNIEXPORT void JNICALL Java_jj2000_j2k_util_NativeServices_setThreadConcurrencyN
    (JNIEnv * env, jclass class, jint level) {
    /* Set the concurrency to 'level' */
    /* The only error that can happen is that 'level' is negative. This is
     * checked on the Java side, so no need to deal with it here */
    pthread_setconcurrency(level);
}


/*
 * Class:     jj2000_j2k_util_NativeServices
 * Method:    getThreadConcurrencyN
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_jj2000_j2k_util_NativeServices_getThreadConcurrencyN
    (JNIEnv * env, jclass class) {
    /* Just return the concurrency. No errors can occur. */
    return pthread_getconcurrency();
}
